==> knative-client-4.7.1-sources.jar: io/fabric8/knative/client/eventing/v1alpha1/internal/TriggerOperationsImpl.java <==

/**
 * Copyright (C) 2015 Red Hat, Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

                        

package io.fabric8.knative.client.eventing.v1alpha1.internal;

import io.fabric8.kubernetes.client.Config;
import io.fabric8.kubernetes.client.dsl.Resource;
import io.fabric8.kubernetes.client.dsl.base.HasMetadataOperation;
import io.fabric8.kubernetes.client.dsl.NonNamespaceOperation;
import io.fabric8.kubernetes.client.utils.ApiVersionUtil;
import io.fabric8.kubernetes.client.dsl.base.OperationContext;

import okhttp3.OkHttpClient;

import io.fabric8.knative.eventing.v1alpha1.DoneableTrigger;
import io.fabric8.knative.eventing.v1alpha1.Trigger;
import io.fabric8.knative.eventing.v1alpha1.TriggerList;
import io.fabric8.knative.eventing.v1alpha1.DoneableTrigger;

import java.util.Map;
import java.util.TreeMap;


public class TriggerOperationsImpl extends HasMetadataOperation<Trigger, TriggerList, DoneableTrigger, Resource<Trigger, DoneableTrigger>> {

  public TriggerOperationsImpl(OkHttpClient client, Config config) {
    this(new OperationContext().withOkhttpClient(client).withConfig(config));
  }

  public TriggerOperationsImpl(OperationContext context) {
    super(context.withApiGroupName("eventing.knative.dev")
    .withApiGroupVersion("v1alpha1")
    .withPlural("triggers"));
    this.type = Trigger.class;
    this.listType = TriggerList.class;
    this.doneableType = DoneableTrigger.class;
  }

  public TriggerOperationsImpl newInstance(OperationContext context) {
    return new TriggerOperationsImpl(context);
  }
}

==> knative-client-4.10.0-sources.jar: io/fabric8/knative/client/eventing/v1alpha1/internal/TriggerOperationsImpl.java <==


                        

package io.fabric8.knative.client.eventing.v1alpha1.internal;

import io.fabric8.kubernetes.client.Config;
import io.fabric8.kubernetes.client.dsl.Resource;
import io.fabric8.kubernetes.client.dsl.base.HasMetadataOperation;
import io.fabric8.kubernetes.client.dsl.NonNamespaceOperation;
import io.fabric8.kubernetes.client.utils.ApiVersionUtil;
import io.fabric8.kubernetes.client.dsl.base.OperationContext;

import okhttp3.OkHttpClient;

import io.fabric8.knative.eventing.v1alpha1.DoneableTrigger;
import io.fabric8.knative.eventing.v1alpha1.Trigger;
import io.fabric8.knative.eventing.v1alpha1.TriggerList;
import io.fabric8.knative.eventing.v1alpha1.DoneableTrigger;

import java.util.Map;
import java.util.TreeMap;


public class TriggerOperationsImpl extends HasMetadataOperation<Trigger, TriggerList, DoneableTrigger, Resource<Trigger, DoneableTrigger>> {

  public TriggerOperationsImpl(OkHttpClient client, Config config) {
    this(new OperationContext().withOkhttpClient(client).withConfig(config).withPropagationPolicy(DEFAULT_PROPAGATION_POLICY));
  }

  public TriggerOperationsImpl(OperationContext context) {
    super(context.withApiGroupName("eventing.knative.dev")
    .withApiGroupVersion("v1alpha1")
    .withPlural("triggers"));
    this.type = Trigger.class;
    this.listType = TriggerList.class;
    this.doneableType = DoneableTrigger.class;
  }

  public TriggerOperationsImpl newInstance(OperationContext context) {
    return new TriggerOperationsImpl(context);
  }
}
